@@ -163,6 +163,7 @@ public class ConfigurationDefaults {
     def.put("IPV4 Prefer Stack", FALSE );
     def.put(ConfigKeys.Connection.BCFG_IPV_4_IGNORE_NI_ADDRESSES, FALSE );
     def.put(ConfigKeys.Connection.BCFG_IPV_6_IGNORE_NI_ADDRESSES, FALSE );
+    def.put(ConfigKeys.Connection.SCFG_CONNECTION_TEST_DOMAIN, "www.google.com");
 
     def.put("max active torrents", new Long(4));
     def.put("max downloads", new Long(4));
@@ -323,7 +324,8 @@ public class ConfigurationDefaults {
 
 	def.put("Default save path", f.getAbsolutePath());
 	def.put("saveTo_list.max_entries", new Long(15));
-
+	def.put(ConfigKeys.File.BCFG_ALWAYS_CREATE_TORRENT_SUB_FOLDER, FALSE );
+	
     def.put("update.start",TRUE);
     def.put("update.periodic",TRUE);
     def.put("update.opendialog",TRUE);
@@ -412,12 +414,14 @@ public class ConfigurationDefaults {
     def.put( "Start Watched Torrents Stopped", FALSE );	// removed, use mode below, migrated in checker
     def.put( "Watch Torrents Add Mode", ZERO );
     def.put( "Watch Torrent Always Rename", FALSE );
+    def.put( ConfigKeys.File.BCFG_WATCH_TORRENT_USE_TOD, FALSE );
     def.put( "Watch Torrent Folder Path", "" );
     def.put( "Watch Torrent Folder Path Count", ONE );
     def.put( ConfigKeys.Transfer.BCFG_PRIORITIZE_FIRST_PIECE, FALSE );
     def.put( ConfigKeys.Transfer.ICFG_PRIORITIZE_FIRST_MB, 0 );
     def.put( ConfigKeys.Transfer.BCFG_PRIORITIZE_FIRST_PIECE_FORCE, FALSE );
     def.put( "Prioritize Most Completed Files", FALSE );
+    def.put( ConfigKeys.Transfer.ICFG_SET_FILE_PRIORITY_REM_PIECE, ZERO );
     def.put( "Piece Picker Request Hint Enabled", TRUE );
     def.put( "Use Lazy Bitfield", FALSE );
     def.put( "Zero New", FALSE );
@@ -489,7 +493,7 @@ public class ConfigurationDefaults {
     def.put( "Stats File", StatsWriterPeriodic.DEFAULT_STATS_FILE_NAME );
     def.put( "long.term.stats.enable", TRUE );
     def.put( "long.term.stats.weekstart", Calendar.SUNDAY );
-    def.put( "Stats Smoothing Secs", new Long( 2*60 ));
+    def.put( ConfigKeys.Stats.ICFG_STATS_SMOOTHING_SECS, new Long( GeneralUtils.SMOOTHING_UPDATE_WINDOW_DEFAULT ));
     def.put( "File.Torrent.AutoSkipExtensions", "" );
     def.put( "File.Torrent.AutoSkipFiles", "" );
     def.put( "File.Torrent.AutoSkipFiles.RegExp", FALSE );
@@ -620,7 +624,9 @@ public class ConfigurationDefaults {
     def.put( "Auto Update", TRUE );
     def.put( "Alert on close", FALSE );
     def.put( "diskmanager.hashchecking.strategy", ONE );
-    def.put( "diskmanager.hashchecking.smallestfirst", TRUE );
+    def.put( ConfigKeys.File.BCFG_DISKMANAGER_HASHCHECKING_SMALLESTFIRST, TRUE );
+    def.put( ConfigKeys.File.BCFG_DISKMANAGER_ALLOC_SMALLESTFIRST, TRUE );
+    def.put( ConfigKeys.File.BCFG_DISKMANAGER_MOVE_SMALLESTFIRST, TRUE );
     def.put( ConfigKeys.File.BCFG_DISKMANAGER_ONE_OP_PER_FS, FALSE );
     def.put( ConfigKeys.File.BCFG_DISKMANAGER_ONE_OP_PER_FS_CONC_READ, FALSE );
     def.put( "diskmanager.hashchecking.maxactive", ONE );
@@ -810,16 +816,6 @@ public class ConfigurationDefaults {
     def.put( "subscriptions.auto.start.max.mb", ZERO );
     def.put( "subscriptions.auto.dl.mark.read.days", ZERO );
 
-    def.put( "Show Side Bar", TRUE );
-    def.put( "Side Bar Top Level Gap", ONE );
-    def.put( "Show Options In Side Bar", FALSE );
-    def.put( "Show New In Side Bar", TRUE );
-    def.put( "Show Downloading In Side Bar", TRUE );
-    def.put( "Side Bar Close Position", ZERO );
-    def.put( "Side Bar Indent Expanders", TRUE );
-    def.put( "Side Bar Compact View", FALSE );
-    def.put( "Side Bar Hide Left Icon", FALSE );
-    
     def.put( "Share Ratio Progress Interval", 1000L );	// thousandths
 
     def.put( "search.showRCMView", FALSE );
