@@ -857,7 +857,7 @@ FMFileImpl
 	
 
 		// file reservation is used to manage the possibility of multiple torrents
-		// refering to the same file. Initially introduced to stop a common problem
+		// referring to the same file. Initially introduced to stop a common problem
 		// whereby different torrents contain the same files - without
 		// this code the torrents could interfere resulting in all sorts of problems
 		// The original behavior was to completely prevent the sharing of files.
@@ -1089,10 +1089,11 @@ FMFileImpl
 					}
 				}
 				
-
-				Debug.out( "reserveAccess fail" );
+				String str = "File '"+canonical_path+"' is in use by '" + (users_sb==null?"eh?":users_sb.toString()) +"'";
 				
-				throw( new FMFileManagerException( "File '"+canonical_path+"' is in use by '" + (users_sb==null?"eh?":users_sb.toString()) +"'"));
+				Debug.out( "reserveAccess fail: " + str );
+				
+				throw( new FMFileManagerException( str ));
 			}
 
 		}finally{
@@ -1261,13 +1262,23 @@ FMFileImpl
 	{
 		File cPath = FileUtil.newFile(canonical_path);
 		String sPaths;
-		if (cPath.equals(linked_file))
+		
+		FileAccessor current_fa = fa;
+		
+		String fa_str = current_fa==null?"null":current_fa.getString();
+		
+		if (cPath.equals(linked_file)){
+			
 			sPaths = "can/link=" + Debug.secretFileName(canonical_path);
-		else
+			
+		}else{
+			
 			sPaths = "can=" + Debug.secretFileName(canonical_path) + ",link="
 					+ Debug.secretFileName(linked_file.toString());
-		return sPaths + ",fa=" + fa + ",acc=" + access_mode + ",ctrl = "
-				+ file_access.getString();
+		}
+		
+		return sPaths + ",fa=" + fa_str + ",acc=" + access_mode + ",ctrl={"
+				+ file_access.getString()+ "}";
 	}
 
 	protected static void
