@@ -202,11 +202,11 @@ FMFileManagerImpl
 	{
 			// this function works on the currently defined links and will only accept
 			// them as valid if their 'from' location matches the 'file' being queried.
-			// if not the origial file is returned, NOT null
+			// if not the original file is returned, NOT null
 
 			// These semantics are important during file-move operations as the move-file
 			// logic does not update links until AFTER the move is complete. If we don't
-			// verify the 'from' path in this case then teh old existing linkage overrides
+			// verify the 'from' path in this case then the old existing linkage overrides
 			// the new destination during the move process and causes it to fail with
 			// 'file already exists'. There is possibly an argument that we shouldn't
 			// take links into account when moving
@@ -504,6 +504,91 @@ FMFileManagerImpl
 			writer.exdent();
 		}
 	}
+	
+	protected void
+	generate(
+		IndentWriter	writer,
+		TOTorrent		torrent )
+	{
+		writer.println( "FMFileManager slots" );
+
+		try{
+			HashWrapper hw = torrent.getHashWrapper();
+			
+			try{
+				writer.indent();
+	
+				try{
+					map_mon.enter();
+	
+					Iterator it = map.keySet().iterator();
+	
+					while( it.hasNext()){
+	
+						FMFileLimited	file = (FMFileLimited)it.next();
+	
+						if ( file.getOwner().getTorrentFile().getTorrent().getHashWrapper() == hw ){
+						
+							writer.println( file.getString());
+						}
+					}
+	
+				}finally{
+	
+					map_mon.exit();
+				}
+			}finally{
+	
+				writer.exdent();
+			}
+		}catch( Throwable e ){
+			
+			Debug.out( e );
+		}
+		
+		writer.println( "FMFileManager links" );
+
+		try{			
+			try{
+				writer.indent();
+	
+				try{
+					links_mon.enter();
+	
+					LinkFileMap	links_entry = getLinksEntry( torrent );
+
+					Iterator<LinkFileMap.Entry>	it = links_entry.entryIterator();
+
+					while( it.hasNext()){
+
+						LinkFileMap.Entry	entry = it.next();
+
+						int		index	= entry.getIndex();
+
+						File	source 	= entry.getFromFile();
+						File	target	= entry.getToFile();
+						
+						if ( target != null && !FileUtil.areFilePathsIdentical( source, target )){
+						
+							writer.println( index + ": " + source + " -> " + target );
+						}
+					}
+	
+				}finally{
+	
+					links_mon.exit();
+				}
+			}finally{
+	
+				writer.exdent();
+			}
+		}catch( Throwable e ){
+			
+			Debug.out( e );
+		}
+		
+	}
+	
 	protected static void
 	generateEvidence(
 		IndentWriter	writer )
@@ -512,4 +597,14 @@ FMFileManagerImpl
 
 		singleton.generate( writer );
 	}
+	
+	public void
+	generateEvidence(
+		IndentWriter	writer,
+		TOTorrent		torrent )
+	{
+		getSingleton();
+
+		singleton.generate( writer, torrent );
+	}
 }
