@@ -134,6 +134,13 @@ DownloadManager
     
     public void 
     forceRecheck();
+    
+    	/**
+    	 * Called for certain config change events so that individual managers don't have to separately listener for changes
+    	 */
+    
+    public void
+    syncGlobalConfig();
 
     	/**
          * Reset the file download state to totally undownloaded. Download must be stopped
@@ -238,6 +245,18 @@ DownloadManager
     
     public void
     resume();
+    
+    	/**
+    	 * resume the download and wait until it reaches the target state. It may fail to reach this
+    	 * state (e.g. goes into an error state). It will however block if it looks like progress towards
+    	 * the state is being made (allocating/checking)
+    	 * @param target_state
+    	 * @return whether or not the state was reached
+    	 */
+    
+    public boolean
+    resume(
+    	int		target_state );
 
     public int
     getTCPListeningPortNumber();
@@ -828,10 +847,11 @@ DownloadManager
     public void
     removeTPSListener(
     	DownloadManagerTPSListener		listener );
-
+    
     public void
     generateEvidence(
-        IndentWriter        writer );
+        IndentWriter        writer,
+        boolean				full );
 
     public int[] getStorageType(DiskManagerFileInfo[] infos);
 
