@@ -87,13 +87,17 @@ DownloadManagerState
 	public static final String AT_MOVE_ON_COMPLETE_DIR		= "moc.dir";		// String - explicit move-on-complete folder
 	public static final String AT_FILE_FLAGS				= "ff";
 	public static final String AT_FILE_ALLOC_STRATEGY		= "fas";			// long
+	public static final String AT_FILE_ALLOC_ORDER			= "fao";			// long
 	public static final String AT_TRACKER_SESSION_STATS		= "tss";			// Map
 	public static final String AT_TORRENT_SAVE_TIME			= "tst";			// long
 	public static final String AT_TORRENT_EXPORT_PROPAGATED	= "tep";			// bool
 	public static final String AT_SWARM_TAGS				= "stag";			// list
 	public static final String AT_MASK_DL_COMP_OPTIONAL		= "mdlc";			// Boolean (optional)
 	public static final String AT_REAL_DM_MAGNET_TIME		= "rdmmt";			// long
-	
+	public static final String AT_PLUGIN_OPTIONS			= "pluginoptions";	// Map
+	public static final String 		AT_PO_ENABLE_ANNOUNCE		= "enableannounce";		// boolean, def=true
+	public static final String AT_SET_FILE_PRIORITY_REM_PIECE	= "sfp.rp";		// int
+
 	public static final String AT_TRANSIENT_FLAGS			= "t_flags";
 	public static final String AT_TRANSIENT_TAG_SORT		= "t_tagsort";
 
@@ -108,6 +112,7 @@ DownloadManagerState
 		{ AT_REORDER_MIN_MB,						new Integer( -1 )},
 		{ AT_SHARE_RATIO_PROGRESS,					new Long( 0 )},
 		{ AT_FILE_ALLOC_STRATEGY,					new Long( FAS_DEFAULT )},
+		{ AT_FILE_ALLOC_ORDER,						new Long( -1 )},
 	};
 
 	public static final long FLAG_ONLY_EVER_SEEDED						= Download.FLAG_ONLY_EVER_SEEDED;
@@ -474,7 +479,7 @@ DownloadManagerState
 	 */
 	boolean parameterExists(String name);
 
-	public void generateEvidence(IndentWriter writer);
+	public void generateEvidence(IndentWriter writer, boolean full );
 
 	public void dump( IndentWriter writer );
 
