@@ -30,6 +30,7 @@ import com.biglybt.core.config.COConfigurationManager;
 import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.disk.*;
 import com.biglybt.core.disk.impl.DiskManagerUtil;
+import com.biglybt.core.diskmanager.file.FMFileManagerFactory;
 import com.biglybt.core.download.*;
 import com.biglybt.core.download.DownloadManagerState.ResumeHistory;
 import com.biglybt.core.global.GlobalManager;
@@ -3124,14 +3125,13 @@ DownloadManagerController
 							public void stateChanged(DiskManager dm, int oldState, int newState) {}
 
 							@Override
-							public void filePriorityChanged(DiskManager dm, DiskManagerFileInfo file) {
+							public void filePriorityChanged(DiskManager dm, List<DiskManagerFileInfo> files) {
 								if (initialising[0]) {
-									delayed_prio_changes.add(file);
+									delayed_prio_changes.addAll(files);
 								} else {
-									download_manager.informPriorityChange(file);
+									download_manager.informPriorityChange(files);
 								}
 							}
-
 							@Override
 							public void pieceDoneChanged(DiskManager dm, DiskManagerPiece piece) {}
 							
@@ -3570,7 +3570,11 @@ DownloadManagerController
 		}
 	}
 
-	public void generateEvidence(IndentWriter writer) {
+	public void 
+	generateEvidence(
+		IndentWriter writer,
+		boolean		full )
+	{
 		writer.println("DownloadManager Controller:");
 
 		writer.indent();
@@ -3588,6 +3592,34 @@ DownloadManagerController
 			}
 
 			writer.println("FilesExist? " + filesExist(download_manager.isDataAlreadyAllocated()));
+			
+			if ( full ){
+				
+				DiskManagerFileInfo[] files = fileFacadeSet.getFiles();
+				
+				writer.println( "Files" );
+				
+				try{
+					writer.indent();
+					
+					for ( DiskManagerFileInfo file: files ){
+						
+						File f = file.getFile( true );
+								
+						writer.println( file.getIndex() + ": " + f + ", exists=" + f.exists());
+					}
+				}finally{
+					
+					writer.exdent();
+				}
+				
+				TOTorrent torrent = download_manager.getTorrent();
+				
+				if ( torrent != null ){
+				
+					FMFileManagerFactory.getSingleton().generateEvidence( writer, torrent );
+				}
+			}
 
 		} finally {
 			writer.exdent();
@@ -3729,10 +3761,10 @@ DownloadManagerController
 				}
 			}
 		}
-
+		
 		@Override
-		public void filePriorityChanged(DiskManager	dm, DiskManagerFileInfo file) {
-			download_manager.informPriorityChange(file);
+		public void filePriorityChanged(DiskManager	dm, List<DiskManagerFileInfo> files) {
+			download_manager.informPriorityChange(files);
 		}
 
 		@Override
@@ -3864,20 +3896,21 @@ DownloadManagerController
 		}
 
 		@Override
-		public void
+		public void 
 		filePriorityChanged(
-			DiskManager			dm, 
-			DiskManagerFileInfo	file )
+			DiskManager dm, 
+			List<DiskManagerFileInfo> files )
 		{
-			download_manager.informPriorityChange( file );
+			download_manager.informPriorityChange( files );
 		}
-
+		
 		@Override
 		public void
 		pieceDoneChanged(
 			DiskManager			dm, 
 			DiskManagerPiece	piece )
 		{
+			download_manager.informPieceDoneChanged( piece );
 		}
 		
 		@Override
