@@ -226,7 +226,7 @@ CoreImpl
 	
 	private boolean					ll_started;
 	
-	private final List<CoreOperationListener>				operation_listeners		= new ArrayList<>();
+	private final CopyOnWriteList<CoreOperationListener>	operation_listeners		= new CopyOnWriteList<>();
 	private final CopyOnWriteList<CoreOperation>			operations				= new CopyOnWriteList<>();
 	
 	private final CopyOnWriteList<PowerManagementListener>	power_listeners = new CopyOnWriteList<>();
@@ -3226,7 +3226,7 @@ CoreImpl
 		CoreOperationTask 		task )
 	{
 		CoreOperation op =
-				new CoreOperation()
+				new CoreOperation.CoreOperationAdapter()
 				{
 					@Override
 					public int
@@ -3281,7 +3281,15 @@ CoreImpl
 	addOperation(
 		CoreOperation		op )
 	{
-		operations.add( op );
+		synchronized( operations ){
+			
+			if ( op.isRemoved()){
+				
+				return;
+			}
+
+			operations.add( op );
+		}
 		
 		for ( CoreOperationListener l: operation_listeners ){
 			
@@ -3300,7 +3308,16 @@ CoreImpl
 	removeOperation(
 		CoreOperation		op )
 	{
-		if ( operations.remove( op )){
+		boolean was_added;
+		
+		synchronized( operations ){
+			
+			was_added = operations.remove( op );
+				
+			op.setRemoved();
+		}
+		
+		if ( was_added ){
 		
 			for ( CoreOperationListener l: operation_listeners ){
 				
