@@ -340,6 +340,25 @@ LWSTorrent
 		throw( new TOTorrentException( "Not supported", TOTorrentException.RT_CREATE_FAILED ));
 	}
 	
+   	@Override
+	public TOTorrent
+	setSimpleTorrentDisabled(
+		boolean	disabled )
+	
+		throws TOTorrentException
+	{
+   		throw( new TOTorrentException( "Not supported", TOTorrentException.RT_CREATE_FAILED ));
+	}
+	
+	@Override
+	public boolean
+	isSimpleTorrentDisabled()
+	
+		throws TOTorrentException
+	{
+		throw( new TOTorrentException( "Not supported", TOTorrentException.RT_CREATE_FAILED ));
+	}
+	
    	@Override
     public void
 	setHashOverride(
