@@ -51,6 +51,25 @@ TOTorrentFile
 	public int
 	getNumberOfPieces();
 
+		/**
+		 * is BEP_47 pad file
+		 * @return
+		 */
+	
+	public boolean
+	isPadFile();
+	
+		/**
+		 * V2 torrents only - also null for zero length files
+		 * @return
+		 */
+	
+	public TOTorrentFileHashTree
+	getHashTree();
+	
+	public byte[]
+	getRootHash();
+	
 	public Map
 	getAdditionalProperties();
 }
