@@ -27,6 +27,7 @@ import java.net.URI;
 import java.net.URL;
 import java.nio.ByteBuffer;
 import java.nio.channels.FileChannel;
+import java.nio.file.FileStore;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.attribute.BasicFileAttributeView;
@@ -44,6 +45,7 @@ import com.biglybt.core.CoreOperationTask;
 import com.biglybt.core.config.COConfigurationListener;
 import com.biglybt.core.config.COConfigurationManager;
 import com.biglybt.core.config.ConfigKeys;
+import com.biglybt.core.config.ConfigUtils;
 import com.biglybt.core.diskmanager.file.impl.FMFileAccess.FileAccessor;
 import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.logging.LogEvent;
@@ -67,14 +69,6 @@ public class FileUtil {
   private static final List		reserved_file_handles 	= new ArrayList();
   private static final AEMonitor	class_mon				= new AEMonitor( "FileUtil:class" );
 
-  private static final Method reflectOnUsableSpace;
-
-  	// FileStore is minSDK 26 on Android
-
-	protected static final Method 	mPath_getFileStore;
-	protected static final Method 	mToPath;
-
-	
   private static char[]	char_conversion_mapping = null;
 
   private static final FileHandler fileHandling;
@@ -93,40 +87,6 @@ public class FileUtil {
 	};
 
   static {
-
-	  Method _reflectOnUsableSpace;
-	
-	  try{
-		  _reflectOnUsableSpace = File.class.getMethod("getUsableSpace", (Class[])null);
-		  
-	  }catch (Throwable e){
-		  
-		  _reflectOnUsableSpace = null;
-	  }
-
-	  reflectOnUsableSpace = _reflectOnUsableSpace;
-	  
-	  
-	  Method 	_mPath_getFileStore;
-	  Method 	_mToPath;
-
-	  try{
-		  Class  _claPath = Class.forName("java.nio.file.Path");
-		  Class  _claFiles = Class.forName("java.nio.file.Files");
-		  _mPath_getFileStore = _claFiles.getMethod("getFileStore", _claPath);
-		  _mToPath = File.class.getMethod("toPath");
-		  
-	  }catch( Throwable e ){
-		  
-		  _mPath_getFileStore	= null;
-		  _mToPath				= null;
-	  }
-	 
-	  mPath_getFileStore	= _mPath_getFileStore;
-	  mToPath				= _mToPath;
-
-	  
-	  
 	  String fileHandlingCN = System.getProperty("az.FileHandling.impl",
 			"");
 	  // To test:
@@ -280,7 +240,7 @@ public class FileUtil {
    */
   public static boolean recursiveDelete(File f) {
     String defSaveDir = COConfigurationManager.getStringParameter("Default save path");
-    String moveToDir = COConfigurationManager.getStringParameter("Completed Files Directory", "");
+    String moveToDir = ConfigUtils.getDefaultMoveOnCompleteFolder( true );
 
     try{
   	  moveToDir = newFile(moveToDir).getCanonicalPath();
@@ -386,7 +346,7 @@ public class FileUtil {
   {
      try {
       String defSaveDir 	= COConfigurationManager.getStringParameter("Default save path");
-      String moveToDir 		= COConfigurationManager.getStringParameter("Completed Files Directory", "");
+      String moveToDir 		= ConfigUtils.getDefaultMoveOnCompleteFolder( true );
 
       if ( defSaveDir.trim().length() > 0 ){
 
@@ -601,7 +561,7 @@ public class FileUtil {
 			// mac file names can end in space - fix this up by getting
 			// the canonical form which removes this on Windows
 
-			// however, for soem reason getCanonicalFile can generate high CPU usage on some user's systems
+			// however, for some reason getCanonicalFile can generate high CPU usage on some user's systems
 			// in  java.io.Win32FileSystem.canonicalize
 			// so changing this to only be used on non-windows
 
@@ -2277,26 +2237,16 @@ public class FileUtil {
 
     		boolean	same_drive = false;
     		
-	    	if ( mToPath != null && mPath_getFileStore != null ){
 				try{
-					/* FileStore is minSDK 26 on Android
 					FileStore fs1 = Files.getFileStore( from_file.toPath());
 					FileStore fs2 = Files.getFileStore( to_file_parent.toPath());
-					*/
-	
-					/* Path */ Object from_file_toPath = mToPath.invoke(from_file);
-					/* Path */ Object to_file_parent_toPath = mToPath.invoke(to_file_parent);
-	
-					/* FileStore */ Object fs1 = mPath_getFileStore.invoke(null, from_file_toPath);
-					/* FileStore */ Object fs2 = mPath_getFileStore.invoke(null, to_file_parent_toPath);
-	
+
 	   				if ( fs1.equals( fs2 )){
 	
 	   					same_drive = true;
 	   				}
 				}catch( Throwable e ){
 				}
-	    	}
 			
 	    	boolean	use_copy = COConfigurationManager.getBooleanParameter("Copy And Delete Data Rather Than Move");
 
@@ -3349,15 +3299,10 @@ public class FileUtil {
    		}
    	}
 
-	public static boolean getUsableSpaceSupported()
-	{
-		return reflectOnUsableSpace != null;
-	}
-
 	public static long getUsableSpace(File f)
 	{
 		try{
-			return ((Long)reflectOnUsableSpace.invoke(f)).longValue();
+			return f.getUsableSpace();
 
 		}catch ( Throwable e){
 
@@ -3556,7 +3501,7 @@ public class FileUtil {
 		 * Gets the encoding that should be used when writing script files (currently only
 		 * tested for windows as this is where an issue can arise...)
 		 * We also only test based on the user-data directory name to see if an explicit
-		 * encoding switch is requried...
+		 * encoding switch is required...
 		 * @return null - use default
 		 */
 
@@ -3619,10 +3564,11 @@ public class FileUtil {
 	runFileOpWithTimeout(
 		File					file,
 		FileOpWithTimeout<T>	fo,
-		T						def )
+		T						def,
+		long					strict_timeout )
 	{
 		try{
-			return( runFileOpWithTimeoutEx( file, fo, def, null ));
+			return( runFileOpWithTimeoutEx( file, fo, def, null, strict_timeout ));
 						
 		}catch( Throwable e ){
 			
@@ -3634,12 +3580,13 @@ public class FileUtil {
 	runFileOpWithTimeoutEx(
 		File					file,
 		FileOpWithTimeout<T>	fo,
-		IOException				def_error )
+		IOException				def_error,
+		long					strict_timeout )
 	
 		throws IOException
 	{
 		try{
-			return( runFileOpWithTimeoutEx( file, fo, null, def_error ));
+			return( runFileOpWithTimeoutEx( file, fo, null, def_error, strict_timeout ));
 						
 		}catch( IOException e ){
 			
@@ -3651,12 +3598,15 @@ public class FileUtil {
 		}
 	}
 	
+	private static AsyncDispatcher fot_dispatcher = new AsyncDispatcher( "FOT" );
+	
 	private static <T> T
 	runFileOpWithTimeoutEx(
 		File					file,
 		FileOpWithTimeout<T>	fo,
 		T						def_result,
-		IOException				def_error )
+		IOException				def_error,
+		long					strict_timeout )
 	
 		throws IOException
 	{		
@@ -3680,189 +3630,287 @@ public class FileUtil {
 			}
 		}
 		
-		long	start = SystemTime.getMonotonousTime();
-
-		try{			
-			return( fo.run());
-			
-		}finally{
-			
-			long	elapsed = SystemTime.getMonotonousTime() - start;
-			
-			if ( elapsed > 2500 ){
+		FileOpWithTimeout<T> delegate = ()->{	
+		
+			long	start = SystemTime.getMonotonousTime();
+	
+			try{			
+				return( fo.run());
 				
-				Path root_path = file.toPath().getRoot();
+			}finally{
 				
-				synchronized( bad_roots ){
+				long	elapsed = SystemTime.getMonotonousTime() - start;
+				
+				if ( elapsed > 2500 ){
 					
-					if ( !bad_roots.containsKey(root_path)){
-				
-						if ( bad_roots.size() > 1024 ){
-							
-							Debug.out( "Bad roots size limit exceeded for " + root_path );
-							
-						}else{
-							
-							bad_roots.put(root_path, new int[]{0});
-							
-							if ( bad_roots.size() == 1 ){
+					Path root_path = file.toPath().getRoot();
+					
+					synchronized( bad_roots ){
+						
+						if ( !bad_roots.containsKey(root_path)){
+					
+							if ( bad_roots.size() > 1024 ){
 								
-								AEThread2.createAndStartDaemon( "BadRootChecker", ()->{
+								Debug.out( "Bad roots size limit exceeded for " + root_path );
+								
+							}else{
+								
+								bad_roots.put(root_path, new int[]{0});
+								
+								if ( bad_roots.size() == 1 ){
 									
-									while( true ){								
-										try{
-											Thread.sleep( 30*1000 );
-											
-										}catch( Throwable e ){
-											
-										}
+									AEThread2.createAndStartDaemon( "BadRootChecker", ()->{
 										
-										Map<Path, int[]> to_check;
-										
-										synchronized( bad_roots ){
-											
-											to_check = new HashMap<>( bad_roots );										
-										}
-										
-										for ( Map.Entry<Path,int[]> entry: to_check.entrySet()){
-											
+										while( true ){								
 											try{
-												long check_start = SystemTime.getMonotonousTime();
+												Thread.sleep( 30*1000 );
 												
-												int limit = 250;
-												
-												Path	path	= entry.getKey();
-												int[]	oks		= entry.getValue();
-														
-												File 	check_file	= path.toFile();
-outer:
-												for ( int i=0;; i++){
-													
-													switch(i){
-														case 0:{
-															check_file.getCanonicalPath();
-															break;
-														}
-														case 1:{
-															check_file.exists();
-															break;
-														}
-														case 2:{
-															check_file.length();
-															break;
-														}
-														case 3:{
-															check_file.isDirectory();
-															break;
-														}
-														case 4:{
-															File random_file = new File( check_file, "Test" + RandomUtils.nextAbsoluteLong() + ".dat" );
-
-															if ( random_file.isFile()){
-															
-																Thread.sleep(limit);
-															}
-															
-															break;
-														}
-														case 5:{
-															check_file.listFiles();
-															break;
-														}
-														default:{
-															break outer;
-														}
-													}
-													
-													if ( SystemTime.getMonotonousTime() - check_start >= limit ){
-														
-														break;
-													}
-												}												
-												
-												if ( SystemTime.getMonotonousTime() - check_start < limit ){
-													
-													oks[0]++;
-													
-													if ( oks[0] > 2 ){
-														
-														Debug.out( "Root path " + path + " appears to be responding in a timely manner, enabling" );
-														
-														synchronized( bad_roots ){
-															
-															bad_roots.remove( path );
-															
-															if ( bad_roots.isEmpty()){
-																
-																return;
-															}
-														}
-													}
-												}else{
-													
-													oks[0] = 0;
-												}
 											}catch( Throwable e ){
 												
 											}
+											
+											Map<Path, int[]> to_check;
+											
+											synchronized( bad_roots ){
+												
+												to_check = new HashMap<>( bad_roots );										
+											}
+											
+											for ( Map.Entry<Path,int[]> entry: to_check.entrySet()){
+												
+												try{
+													long check_start = SystemTime.getMonotonousTime();
+													
+													int limit = 250;
+													
+													Path	path	= entry.getKey();
+													int[]	oks		= entry.getValue();
+															
+													File 	check_file	= path.toFile();
+	outer:
+													for ( int i=0;; i++){
+														
+														switch(i){
+															case 0:{
+																check_file.getCanonicalPath();
+																break;
+															}
+															case 1:{
+																check_file.exists();
+																break;
+															}
+															case 2:{
+																check_file.length();
+																break;
+															}
+															case 3:{
+																check_file.isDirectory();
+																break;
+															}
+															case 4:{
+																File random_file = new File( check_file, "Test" + RandomUtils.nextAbsoluteLong() + ".dat" );
+	
+																if ( random_file.isFile()){
+																
+																	Thread.sleep(limit);
+																}
+																
+																break;
+															}
+															case 5:{
+																check_file.listFiles();
+																break;
+															}
+															default:{
+																break outer;
+															}
+														}
+														
+														if ( SystemTime.getMonotonousTime() - check_start >= limit ){
+															
+															break;
+														}
+													}												
+													
+													if ( SystemTime.getMonotonousTime() - check_start < limit ){
+														
+														oks[0]++;
+														
+														if ( oks[0] > 2 ){
+															
+															Debug.out( "Root path " + path + " appears to be responding in a timely manner, enabling" );
+															
+															synchronized( bad_roots ){
+																
+																bad_roots.remove( path );
+																
+																if ( bad_roots.isEmpty()){
+																	
+																	return;
+																}
+															}
+														}
+													}else{
+														
+														oks[0] = 0;
+													}
+												}catch( Throwable e ){
+													
+												}
+											}
 										}
-									}
-								});
+									});
+								}
+							
+								Debug.out( "Root path " + root_path + " isn't responding in a timely manner, disabling" );
 							}
-						
-							Debug.out( "Root path " + root_path + " isn't responding in a timely manner, disabling" );
 						}
 					}
 				}
 			}
+		};
+		
+		if ( strict_timeout == -1 ){
+		
+			return( delegate.run());
+			
+		}else{
+			
+			AESemaphore sem = new AESemaphore( "FOT" );
+			
+			Object[] result = { null };
+			
+			fot_dispatcher.dispatch(()->{
+				
+				try{
+					
+					T r = delegate.run();
+					
+					synchronized( result ){
+						
+						result[0] = r;
+					}
+				}catch( IOException e ){
+					
+					synchronized( result ){
+					
+						result[0] = e;
+					}
+					
+				}finally{
+				
+					sem.release();
+				}
+			});
+			
+			if ( sem.reserve( strict_timeout )){
+				
+				synchronized( result ){
+					
+					Object r = result[0];
+					
+					if ( r instanceof IOException ){
+						
+						throw((IOException)r);
+					}else{
+						
+						return((T)r);
+					}
+				}
+			}else{
+				
+				return( def_result );
+			}
 		}
 	}
 	
 	public static long
 	lengthWithTimeout(
 		File		file )
+	{
+		return( lengthWithTimeout(file, -1 ));
+	}
+	
+	public static long
+	lengthWithTimeout(
+		File		file,
+		long		strict_timeout )
 	{
 		return(runFileOpWithTimeout(file,()->{
 			return( file.length());
-		},0L));
+		},0L, strict_timeout ));
 	}
 	
 	public static boolean
 	canReadWithTimeout(
 		File		file )
+	{
+		return( canReadWithTimeout(file, -1 ));
+	}
+	
+	public static boolean
+	canReadWithTimeout(
+		File		file,
+		long		strict_timeout )
 	{
 		return(runFileOpWithTimeout(file,()->{
 			return( file.canRead());
-		},false));
+		},false, strict_timeout ));
 	}
 
 	public static boolean
 	isDirectoryWithTimeout(
 		File		file )
+	{
+		return( isDirectoryWithTimeout( file, -1 ));
+	}
+	
+	public static boolean
+	isDirectoryWithTimeout(
+		File		file,
+		long		strict_timeout )
 	{
 		return(runFileOpWithTimeout(file,()->{
 			return( file.isDirectory());
-		},false));	
+		},false, strict_timeout ));	
 	}
 	
 	public static boolean
 	existsWithTimeout(
 		File		file )
+	{
+		return( existsWithTimeout( file, -1 ));
+	}
+	
+	public static boolean
+	existsWithTimeout(
+		File		file,
+		long		strict_timeout )
 	{
 		return(runFileOpWithTimeout(file,()->{
 			return( file.exists());
-		},false));	
+		},false, strict_timeout ));	
 	}
 	
 	public static String
 	getCanonicalPathWithTimeout(
 		File		file )
 	
+		throws IOException
+	{
+		return( getCanonicalPathWithTimeout( file, -1 ));
+	}
+	
+	public static String
+	getCanonicalPathWithTimeout(
+		File		file,
+		long		strict_timeout )
+	
 		throws IOException
 	{
 		return(runFileOpWithTimeoutEx(file,()->{
 			return( file.getCanonicalPath());
-		}, new IOException( "File system not responding/slow" )));	
+		}, new IOException( "File system not responding/slow" ), strict_timeout ));	
 	}
 	
 	private static volatile File[]	last_roots = {};
@@ -3873,6 +3921,13 @@ outer:
     
 	public static File[]
 	listRootsWithTimeout()
+	{
+		return( listRootsWithTimeout( 250 ));
+	}
+	
+	public static File[]
+	listRootsWithTimeout(
+		long		timeout )
 	{	
 		long now = SystemTime.getMonotonousTime();
 		
@@ -3918,7 +3973,7 @@ outer:
 			}
 		}
 		
-		sem.reserve( 250 );
+		sem.reserve( timeout );
 		
 		return( last_roots );
 	}
