@@ -532,8 +532,12 @@ ClientIDManagerImpl
 				int	p1 = get.indexOf( "?cid=" );
 				int	p2 = get.indexOf( "&", p1 );
 
-				if( p2 == -1 ){
+				boolean url_has_no_args = false;
+				
+				if ( p2 == -1 ){
 
+					url_has_no_args = true;
+					
 					p2 = get.indexOf( ' ', p1 );
 				}
 
@@ -584,7 +588,16 @@ ClientIDManagerImpl
 					}
 				}
 
-				get = get.substring( 0, p1+1 ) + get.substring( p2+1 );
+				if ( url_has_no_args ){
+					
+					get = get.substring( 0, p1 ) + get.substring( p2 );
+					
+				}else{
+				
+						// include the "?" from cid and drop the "&" from the remainder
+					
+					get = get.substring( 0, p1+1 ) + get.substring( p2+1 );
+				}
 
 				lines_in[0] = get;
 
