@@ -103,6 +103,7 @@ DHTPlugin
 	public static final int			NW_MAIN				= DHT.NW_AZ_MAIN;
 	
 	public static final int			NW_AZ_MAIN			= DHT.NW_AZ_MAIN;
+	public static final int			NW_AZ_MAIN_V6		= DHT.NW_AZ_MAIN_V6;
 	public static final int			NW_AZ_CVS			= DHT.NW_AZ_CVS;
 	public static final int			NW_BIGLYBT_MAIN		= DHT.NW_BIGLYBT_MAIN;
 
@@ -114,7 +115,7 @@ DHTPlugin
 	private static final String PLUGIN_RESOURCE_ID		= "ConfigView.section.plugins.dht";
 
 	private static final boolean	AZ_MAIN_DHT_ENABLE			= COConfigurationManager.getBooleanParameter( "dht.net.main_v4.enable", true );
-	private static final boolean	AZ_CVS_DHT_ENABLE			= COConfigurationManager.getBooleanParameter( "dht.net.cvs_v4.enable", true );
+	private static final boolean	AZ_CVS_DHT_ENABLE			= COConfigurationManager.getBooleanParameter( "dht.net.cvs_v4.enable", false );	// disabled, no longer of any use
 	private static final boolean	AZ_MAIN_DHT_V6_ENABLE		= COConfigurationManager.getBooleanParameter( "dht.net.main_v6.enable", true );
 	private static final boolean	BIGLYBT_MAIN_DHT_ENABLE		= COConfigurationManager.getBooleanParameter( "dht.net.biglybt_main_v4.enable", true );
 
@@ -1026,7 +1027,7 @@ DHTPlugin
 										run()
 										{
 											try{
-												List	plugins = new ArrayList();
+												List<DHTPluginImpl>	plugins = new ArrayList<>();
 
 													// adapter only added to first DHTPluginImpl we create
 
@@ -1051,6 +1052,7 @@ DHTPlugin
 
 													main_dht =
 														new DHTPluginImpl(
+																	DHTPlugin.this,
 																	plugin_interface,
 																	CoreFactory.getSingleton().getNATTraverser(),
 																	adapter,
@@ -1073,6 +1075,7 @@ DHTPlugin
 
 													main_v6_dht =
 														new DHTPluginImpl(
+															DHTPlugin.this,
 															plugin_interface,
 															CoreFactory.getSingleton().getNATTraverser(),
 															adapter,
@@ -1095,6 +1098,7 @@ DHTPlugin
 
 													cvs_dht =
 														new DHTPluginImpl(
+															DHTPlugin.this,
 															plugin_interface,
 															CoreFactory.getSingleton().getNATTraverser(),
 															adapter,
@@ -1117,6 +1121,7 @@ DHTPlugin
 
 													biglybt_dht =
 														new DHTPluginImpl(
+															DHTPlugin.this,
 															plugin_interface,
 															CoreFactory.getSingleton().getNATTraverser(),
 															adapter,
@@ -1683,37 +1688,23 @@ DHTPlugin
 
 	public List<DHTPluginValue>
 	getValues(
-		int			network,
-		boolean		ipv6 )
-	{
+		int			network )
+	{	
 		DHTPluginImpl	dht = null;
 
-		if ( network == NW_AZ_MAIN ){
-
-			if ( ipv6 ){
-
-				dht = main_v6_dht;
-
-			}else{
-
+		switch( network ){
+			case NW_AZ_MAIN:
 				dht = main_dht;
-			}
-		}else if ( network == NW_BIGLYBT_MAIN ){
-			
-			if ( ipv6 ){
-
-				dht = null;
-
-			}else{
-
-				dht = biglybt_dht;
-			}
-		}else{
-
-			if ( !ipv6 ){
-
+				break;
+			case NW_AZ_MAIN_V6:
+				dht = main_v6_dht;
+				break;
+			case NW_AZ_CVS:
 				dht = cvs_dht;
-			}
+				break;
+			case NW_BIGLYBT_MAIN:
+				dht = biglybt_dht;
+				break;
 		}
 
 		if ( dht == null ){
@@ -2337,6 +2328,18 @@ DHTPlugin
 		InetSocketAddress				address,
 		byte							version,
 		boolean							is_cvs )
+	{
+		int	preferred_net = is_cvs?DHT.NW_AZ_CVS:DHT.NW_AZ_MAIN;
+
+		return( importContact( address, version, preferred_net ));
+	}
+
+	@Override
+	public DHTPluginContact
+	importContact(
+		InetSocketAddress				address,
+		byte							version,
+		int								preferred_net )
 	{
 		if ( !isEnabled()){
 
@@ -2345,11 +2348,9 @@ DHTPlugin
 
 		InetAddress contact_address = address.getAddress();
 
-		int	target_network = is_cvs?DHT.NW_AZ_CVS:DHT.NW_AZ_MAIN;
-
 		for ( DHTPluginImpl dht: dhts ){
 
-			if ( dht.getDHT().getTransport().getNetwork() != target_network ){
+			if ( dht.getDHT().getTransport().getNetwork() != preferred_net ){
 
 				continue;
 			}
@@ -2368,6 +2369,7 @@ DHTPlugin
 		return( importContact( address, version ));
 	}
 
+	
 	@Override
 	public DHTPluginContact
 	getLocalAddress()
@@ -2503,6 +2505,26 @@ DHTPlugin
 		return( null );
 	}
 
+	public DHTPluginBasicInterface
+	getDHTPlugin(
+		int		network )
+	{
+		if ( dhts == null ){
+
+			return( null );
+		}
+
+		for (int i=0;i<dhts.length;i++){
+
+			if ( dhts[i].getDHT().getTransport().getNetwork() == network ){
+
+				return( dhts[i] );
+			}
+		}
+
+		return( null );
+	}
+	
 	@Override
 	public DHTInterface[]
 	getDHTInterfaces()
