@@ -42,6 +42,7 @@ import com.biglybt.core.util.SystemTime;
 import com.biglybt.core.util.TimerEvent;
 import com.biglybt.core.util.UrlUtils;
 import com.biglybt.ui.swt.components.LinkLabel;
+import com.biglybt.ui.swt.components.shell.ShellFactory;
 import com.biglybt.ui.swt.pifimpl.AbstractUISWTInputReceiver;
 import com.biglybt.ui.swt.utils.DragDropUtils;
 
@@ -118,6 +119,11 @@ public class SimpleTextEntryWindow extends AbstractUISWTInputReceiver {
 		if ( parent_shell == null ){
 
 			parent = Display.getDefault().getActiveShell();
+			
+			if ( parent != null && parent.getData( ShellFactory.NOT_A_GOOD_PARENT ) != null ){
+				
+				parent = null;
+			}
 		}
 
 		if (parent == null) {
@@ -127,7 +133,12 @@ public class SimpleTextEntryWindow extends AbstractUISWTInputReceiver {
 
 		display = shell.getDisplay();
 		if (this.title != null) {
-			shell.setText(this.title);
+			String str = this.title;
+			
+			if ( textLimit > 0 ){
+				str += " (" + MessageText.getString( "label.limit") + " " + textLimit + ")";
+			}	
+			shell.setText(str);
 		}
 
 		Utils.setShellIcon(shell);
@@ -471,14 +482,11 @@ public class SimpleTextEntryWindow extends AbstractUISWTInputReceiver {
 			}
 		});
 
-		shell.addListener(SWT.Dispose, new Listener() {
-			@Override
-			public void handleEvent(Event event) {
-				if (!isResultRecorded()) {
-					recordUserAbort();
-				}
-				triggerReceiverListener();
+		shell.addListener(SWT.Dispose, event -> {
+			if (!isResultRecorded()) {
+				recordUserAbort();
 			}
+			Utils.execSWTThreadLater(0, this::triggerReceiverListener);
 		});
 		
 	    shell.pack();
