@@ -24,6 +24,7 @@ import java.io.File;
 import java.text.SimpleDateFormat;
 import java.util.*;
 import java.util.List;
+import java.util.function.Consumer;
 
 import com.biglybt.ui.swt.mainwindow.*;
 import org.eclipse.swt.SWT;
@@ -66,6 +67,7 @@ import com.biglybt.ui.common.table.TableRowCore;
 import com.biglybt.ui.common.table.TableStructureEventDispatcher;
 import com.biglybt.ui.common.util.MenuItemManager;
 import com.biglybt.ui.mdi.MultipleDocumentInterface;
+import com.biglybt.ui.swt.components.shell.ShellFactory;
 import com.biglybt.ui.swt.exporttorrent.wizard.ExportTorrentWizard;
 import com.biglybt.ui.swt.imageloader.ImageLoader;
 import com.biglybt.ui.swt.minibar.DownloadBar;
@@ -426,6 +428,8 @@ public class TorrentMenuFancy
 			}
 		};
 
+		shell.setData( ShellFactory.NOT_A_GOOD_PARENT, "" );
+		
 		//FormLayout shellLayout = new FormLayout();
 		RowLayout shellLayout = new RowLayout(SWT.VERTICAL);
 		shellLayout.fill = true;
@@ -824,14 +828,12 @@ public class TorrentMenuFancy
 			}
 			stop = stop || ManagerUtils.isStopable(dm);
 
-			start = start || ManagerUtils.isStartable(dm);
+			start = start || ManagerUtils.isStartable(dm,true);
 
 			pause = pause || ManagerUtils.isPauseable( dm );
 			
 			recheck = recheck || dm.canForceRecheck();
 
-			boolean stopped = ManagerUtils.isStopped(dm);
-
 			int state = dm.getState();
 			bChangeDir &= (state == DownloadManager.STATE_ERROR
 					|| state == DownloadManager.STATE_STOPPED || state == DownloadManager.STATE_QUEUED);
@@ -853,7 +855,7 @@ public class TorrentMenuFancy
 						if (info.isSkipped()) {
 							continue;
 						}
-						bChangeDir = !info.getFile(true).exists();
+						bChangeDir = !Utils.fileExistsWithTimeout( info.getFile(true));
 						break;
 					}
 				}
@@ -887,7 +889,7 @@ public class TorrentMenuFancy
 				DownloadManager dm = dms[i];
 
 				forceStartEnabled = forceStartEnabled
-						|| ManagerUtils.isForceStartable(dm);
+						|| ManagerUtils.isForceStartable(dm, true );
 
 				forceStart = forceStart || dm.isForceStart();
 			}
@@ -899,7 +901,7 @@ public class TorrentMenuFancy
 					new ListenerDMTask(dms) {
 						@Override
 						public void run(DownloadManager dm) {
-							if (ManagerUtils.isForceStartable(dm)) {
+							if (ManagerUtils.isForceStartable(dm, true )) {
 								dm.setForceStart(newForceStart);
 							}
 						}
@@ -1304,7 +1306,8 @@ public class TorrentMenuFancy
 									allResumeIncomplete = false;
 								}
 								if ( stopped && !hasClearableLinks ){
-									if ( dm.getDiskManagerFileInfoSet().nbFiles() > 1 ){
+									TOTorrent torrent = dm.getTorrent();
+									if ( torrent != null && !torrent.isSimpleTorrent()){
 										if ( dms.getFileLinks().hasLinks()){
 											hasClearableLinks = true;
 										}
@@ -1318,7 +1321,7 @@ public class TorrentMenuFancy
 								
 								lrrecheck = lrrecheck || ManagerUtils.canLowResourceRecheck(dm);
 																
-								allAllocatable &= stopped && !dm.isDataAlreadyAllocated() && !dm.isDownloadComplete( false );	
+								allAllocatable &= ManagerUtils.canAllocate( dm );
 								
 								Boolean dmmask = dms.getOptionalBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL );
 								
@@ -1400,7 +1403,9 @@ public class TorrentMenuFancy
 
 										DiskManagerFileInfoSet fis = dm.getDiskManagerFileInfoSet();
 
-										if ( fis.nbFiles() > 1 ){
+										TOTorrent torrent = dm.getTorrent();
+										
+										if ( torrent != null && !torrent.isSimpleTorrent()){
 
 											DiskManagerFileInfo[] files = fis.getFiles();
 
@@ -1429,13 +1434,9 @@ public class TorrentMenuFancy
 							itemFileAlloc.addListener(SWT.Selection, new ListenerDMTask(
 									dms) {
 								@Override
-								public void run(DownloadManager dm) {
+								public void run(DownloadManager[] dms) {
 									
-									dm.getDownloadState().setLongAttribute( DownloadManagerState.AT_FILE_ALLOC_STRATEGY, DownloadManagerState.FAS_ZERO_NEW_STOP );
-									
-									dm.getDownloadState().setFlag( DownloadManagerState.FLAG_DISABLE_STOP_AFTER_ALLOC, false );
-									
-									ManagerUtils.queue( dm, null );
+									ManagerUtils.allocate( dms );
 								}
 							});
 	
@@ -1534,6 +1535,42 @@ public class TorrentMenuFancy
 							
 							itemMaskDLComp.setEnabled( dms.length > 0 );
 
+								// set file priority when pieces remaining
+							
+							MenuItem itemSetFilePriority = new MenuItem(menu, SWT.PUSH);
+									
+							String sfp_text = MessageText.getString( "ConfigView.label.set.file.pri.pieces.rem" );
+							
+							int sfp_def;
+							
+							if ( dms.length == 1 ){
+								
+								sfp_def = dms[0].getDownloadState().getIntAttribute( DownloadManagerState.AT_SET_FILE_PRIORITY_REM_PIECE );
+								
+								if ( sfp_def > 0 ){
+									
+									sfp_text += " (" + sfp_def + ")";
+								}
+							}else{
+								
+								sfp_def = -1;
+							}
+							
+							itemSetFilePriority.setText(sfp_text+"...");
+							
+							itemSetFilePriority.addListener(SWT.Selection, new ListenerDMTask(dms) {
+								@Override
+								public void run(DownloadManager[] dms) {
+									Utils.numberPrompt( "enter.number", "number.of.pieces", sfp_def>0?sfp_def:null, (num)->{
+										for ( DownloadManager dm: dms ){
+											dm.getDownloadState().setIntAttribute(DownloadManagerState.AT_SET_FILE_PRIORITY_REM_PIECE, num);
+										}
+									});
+								}
+							});
+
+							itemSetFilePriority.setEnabled( dms.length > 0 );					
+							
 							if (userMode > 1 && isSeedingView) {
 
 								boolean canSetSuperSeed = false;
@@ -1598,6 +1635,22 @@ public class TorrentMenuFancy
 								}
 							}
 
+							if ( userMode > 1 ){
+									
+									// view debug
+									
+								MenuItem itemViewDebug = new MenuItem(menu, SWT.PUSH);
+								itemViewDebug.setText( MessageText.getString("StartStopRules.menu.viewDebug") + "..." );
+								itemViewDebug.addListener(SWT.Selection, new ListenerDMTask(dms) {
+									@Override
+									public void 
+									run(
+										DownloadManager[] dms)
+									{
+										ManagerUtils.viewDebug( dms );
+									}
+								});
+							}
 						}
 					});
 		}
@@ -1979,6 +2032,7 @@ public class TorrentMenuFancy
 				new FancyMenuRowInfoListener() {
 					@Override
 					public void buildMenu(Menu menu) {
+						Utils.disposeSWTObjects(menu.getItems());
 						TagUIUtils.addLibraryViewTagsSubMenu(dms, menu);
 					}
 				});
@@ -2156,7 +2210,7 @@ public class TorrentMenuFancy
 
 				File file = dm.getSaveLocation();
 
-				if ( !file.exists()){
+				if ( !Utils.fileExistsWithTimeout( file )){
 					
 					can_share_pers = false;
 					
@@ -2381,6 +2435,22 @@ public class TorrentMenuFancy
 					});
 		}
 
+		if (hasSelection && MenuBuildUtils.hasOpenWithMenu( dms )) {
+			createMenuRow(
+				detailArea,
+				"menu.open.with", null,
+				new FancyMenuRowInfoListener()
+				{
+					@Override
+					public void
+					buildMenu(
+						Menu menuOpenWith )
+					{
+						MenuBuildUtils.addOpenWithMenu( menuOpenWith, true, dms );
+					}
+				});
+		}
+		
 		// Explore (or open containing folder)
 		if (hasSelection) {
 			final boolean use_open_containing_folder = COConfigurationManager.getBooleanParameter("MyTorrentsView.menu.show_parent_folder_enabled");
@@ -2520,7 +2590,6 @@ public class TorrentMenuFancy
 				});
 
 		boolean fileMove 		= true;
-		boolean locateFiles 	= false;
 		boolean	exportFiles		= true;
 		boolean	canSetMOC		= dms.length > 0;
 		boolean canClearMOC		= false;
@@ -2533,14 +2602,6 @@ public class TorrentMenuFancy
 			if ( !dm.canExportDownload()){
 				exportFiles = false;
 			}
-			int state = dm.getState();
-			
-			if ( 	!dm.isDownloadComplete( false ) ||  
-					state == DownloadManager.STATE_ERROR || 
-					state == DownloadManager.STATE_STOPPED ){
-				
-				locateFiles = true;
-			}
 			
 			boolean incomplete = !dm.isDownloadComplete(true);
 
@@ -2590,6 +2651,23 @@ public class TorrentMenuFancy
 						buildMenu(
 							Menu moc_menu )
 						{
+								// existing
+							
+							String existing_moc = TorrentUtil.getMOC( dms );
+							
+							if ( existing_moc != null ){
+								
+								MenuItem existing_item = new MenuItem( moc_menu, SWT.PUSH );
+								
+								existing_item.setText( "[" + existing_moc + "]" );
+								
+								existing_item.setEnabled( false );
+								
+								new MenuItem( moc_menu, SWT.SEPARATOR );
+							}
+							
+								// clear
+							
 							MenuItem clear_item = new MenuItem( moc_menu, SWT.PUSH);
 
 							Messages.setLanguageText( clear_item, "Button.clear" );
@@ -2603,6 +2681,15 @@ public class TorrentMenuFancy
 
 							clear_item.setEnabled( f_canClearMOC );
 							
+								// set
+							
+							Consumer<String> moc_setter = (path)->{
+								
+								MenuBuildUtils.addToMOCHistory( path );
+								
+								TorrentUtil.setMOC( dms, path );
+							};
+							
 							MenuItem set_item = new MenuItem( moc_menu, SWT.PUSH);
 
 							Messages.setLanguageText( set_item, "label.set" );
@@ -2610,11 +2697,16 @@ public class TorrentMenuFancy
 							set_item.addListener(SWT.Selection, new ListenerDMTask(dms) {
 								@Override
 								public void run(DownloadManager[] dms) {
-									TorrentUtil.setMOC(parentShell, dms);
+									TorrentUtil.selectMOC(parentShell, dms, moc_setter );
 								}
 							});
 							
 							set_item.setEnabled( f_canSetMOC );
+							
+							if ( f_canSetMOC ){
+								
+								MenuBuildUtils.addMOCHistory( moc_menu, moc_setter );
+							}
 						}
 					});
 		}
@@ -2636,15 +2728,13 @@ public class TorrentMenuFancy
 					}
 				});
 
-		if ( locateFiles ){
-			createRow(detailArea, "MyTorrentsView.menu.locatefiles", null,
-					new ListenerDMTask(dms) {
-						@Override
-						public void run(DownloadManager[] dms) {
-							ManagerUtils.locateFiles(dms,parentShell);
-						}
-					});
-		}
+		createRow(detailArea, "MyTorrentsView.menu.locatefiles", null,
+				new ListenerDMTask(dms) {
+					@Override
+					public void run(DownloadManager[] dms) {
+						ManagerUtils.locateFiles(dms,parentShell);
+					}
+				});
 
 		if ( dms.length == 1 && ManagerUtils.canFindMoreLikeThis()){
 			createRow(detailArea, "MyTorrentsView.menu.findmorelikethis", null,
