@@ -34,7 +34,7 @@ import com.biglybt.core.util.DisplayFormatters;
 import com.biglybt.core.util.SystemTime;
 import com.biglybt.core.util.UrlUtils;
 import com.biglybt.pif.PluginInterface;
-import com.biglybt.pif.download.DownloadTypeIncomplete;
+import com.biglybt.pif.download.Download;
 import com.biglybt.pif.ui.UIManager;
 import com.biglybt.pif.ui.menus.MenuItem;
 import com.biglybt.pif.ui.menus.MenuItemFillListener;
@@ -66,7 +66,7 @@ public class ColumnProgressETA
 	implements TableCellAddedListener, TableCellMouseListener,
 	TableCellRefreshListener, TableCellSWTPaintListener
 {
-	public static final Class DATASOURCE_TYPE = DownloadTypeIncomplete.class;
+	public static final Class DATASOURCE_TYPE = Download.class;
 
 	public static final String COLUMN_ID = "ProgressETA";
 	public static final long SHOW_ETA_AFTER_MS = 30000;
@@ -92,9 +92,12 @@ public class ColumnProgressETA
 	private final int COLOR_CD	= 1;
 	private final int COLOR_QU	= 2;
 	private final int COLOR_OFF	= 3;
+	private final int COLOR_LS	= 4;
 	
-	private Color[] cDefaults	= new Color[4];
-	private Color[] cExplicits	= new Color[4];
+	private final int[] COLOR_MENU_ORDER = { COLOR_DL, COLOR_CD, COLOR_QU, COLOR_LS, COLOR_OFF };
+	
+	private Color[] cDefaults	= new Color[5];
+	private Color[] cExplicits	= new Color[5];
 
 	private Color cBorder;
 	private Color cText;
@@ -154,7 +157,12 @@ public class ColumnProgressETA
 		if (cDefaults[COLOR_CD] == null) {
 			cDefaults[COLOR_CD] = Colors.green;
 		}
-		
+		// light seeding
+		cDefaults[COLOR_LS] = skinProperties.getColor("color.progress.bg.lightseeding");
+		if (cDefaults[COLOR_LS] == null) {
+			cDefaults[COLOR_LS] = Colors.light_grey;
+		}
+
 		for ( int i=0; i<cExplicits.length; i++ ){
 			
 			COConfigurationManager.addWeakParameterListener(myParameterListener, false,	"ColumnProgressETA.color." + i );
@@ -236,7 +244,7 @@ public class ColumnProgressETA
 				
 				MenuManager menuManager = uim.getMenuManager();
 				
-				for ( int i=0;i<cExplicits.length;i++){
+				for( int i: COLOR_MENU_ORDER ){
 
 					int f_i = i;
 										
@@ -483,7 +491,6 @@ public class ColumnProgressETA
 			return;
 		}
 
-		int lineHeight = cell.getTableRow().getView().getLineHeight();
 		final boolean showSecondLine;
 		int alignSecondLine;
 		Color fgSecondLine;
@@ -493,7 +500,9 @@ public class ColumnProgressETA
 
 		boundsProgressBar.width--;	// adjust as includes pixel for column line :(
 		
-		if (cellBounds.height >= Math.min( minTwoLineHeight, lineHeight*2 )) {
+		final int cellLineCount = cell.getMaxLines();
+
+		if (cellLineCount > 1 || cellBounds.height >= minTwoLineHeight) {
 			showSecondLine = true;
 			boundsProgressBar.height -= secondLineHeight;
 			boundsSecondLine = new Rectangle(
@@ -538,8 +547,16 @@ public class ColumnProgressETA
 			
 			if ( dm_state == DownloadManager.STATE_QUEUED ){
 				
-				cBGIndex = COLOR_QU;
+				int substate = dm.getSubState();
 				
+				if ( substate == DownloadManager.STATE_SEEDING ){
+					
+					cBGIndex = COLOR_LS;
+					
+				}else{
+				
+					cBGIndex = COLOR_QU;
+				}
 			}else{
 			
 				cBGIndex = COLOR_OFF;
