@@ -52,6 +52,21 @@ public class BooleanSwtParameter
 	public interface ValueProcessor
 		extends SwtParameterValueProcessor<BooleanSwtParameter, Boolean>
 	{
+		public default Boolean
+		getValue(
+			List<Boolean>	values )
+		{
+			int intB = -1;
+			for ( boolean v: values ){
+				if (intB == -1) {
+					intB = v ? 1 : 0;
+				} else if ((intB == 1) != v) {
+					intB = 2;
+					break;
+				}
+			}
+			return( intB==2?null:intB == 1 );
+		}
 	}
 
 	private final Label lblSuffix;
