@@ -33,6 +33,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.Map;
 import java.util.List;
+import java.util.Locale;
 import java.util.Set;
 
 import com.biglybt.core.util.*;
@@ -111,7 +112,8 @@ public class FilesViewMenuUtil
 
 		boolean hasSelection = (all_files.size() > 0);
 
-		MenuItem itemOpen = null;
+		MenuItem itemOpen		= null;
+		MenuItem itemOpenWith	= null;
 		
 		if ( !disable_multi_dialog_crud ){
 			
@@ -120,7 +122,9 @@ public class FilesViewMenuUtil
 			Utils.setMenuItemImage(itemOpen, "run");
 			// Invoke open on enter, double click
 			menu.setDefaultItem(itemOpen);
-	
+				
+			itemOpenWith = MenuBuildUtils.addOpenWithMenu( menu, false, all_files );
+			
 			// Explore  (Copied from MyTorrentsView)
 			final boolean use_open_containing_folder = COConfigurationManager.getBooleanParameter("MyTorrentsView.menu.show_parent_folder_enabled");
 			final MenuItem itemExplore = new MenuItem(menu, SWT.PUSH);
@@ -203,21 +207,11 @@ public class FilesViewMenuUtil
 
 			// rename/retarget
 
-		MenuItem itemRenameOrRetarget = null, itemRenameOrRetargetBatch = null, itemRename = null, itemRetarget = null;
-
-		// "Rename or Retarget" -- Opens up file chooser (can choose new dir and new name)
-		itemRenameOrRetarget = new MenuItem(menu, SWT.PUSH);
-		Messages.setLanguageText(itemRenameOrRetarget, "FilesView.menu.rename");
-		itemRenameOrRetarget.setData("rename", Boolean.valueOf(true));
-		itemRenameOrRetarget.setData("retarget", Boolean.valueOf(true));
-		itemRenameOrRetarget.setData("batch", Boolean.valueOf(false));
-		
-		// "Rename or Retarget (Batch)"
-		itemRenameOrRetargetBatch = new MenuItem(menu, SWT.PUSH);
-		Messages.setLanguageText(itemRenameOrRetargetBatch, "FilesView.menu.rename.batch");
-		itemRenameOrRetargetBatch.setData("rename", Boolean.valueOf(true));
-		itemRenameOrRetargetBatch.setData("retarget", Boolean.valueOf(true));
-		itemRenameOrRetargetBatch.setData("batch", Boolean.valueOf(true));
+		MenuItem itemRenameOrRetarget = null;
+		MenuItem itemRenameOrRetargetBatch = null;
+		MenuItem itemRenameDuplicates = null;
+		MenuItem itemRename = null;
+		MenuItem itemRetarget = null;
 
 		// "Quick Rename" -- opens up input box with name
 		itemRename = new MenuItem(menu, SWT.PUSH);
@@ -226,6 +220,38 @@ public class FilesViewMenuUtil
 		itemRename.setData("retarget", Boolean.valueOf(false));
 		itemRename.setData("batch", Boolean.valueOf(false));
 
+		// Rename menu
+		
+		final Menu menuRename = new Menu(menu.getShell(),SWT.DROP_DOWN);
+		final MenuItem itemMmenuRename = new MenuItem(menu, SWT.CASCADE);
+		Messages.setLanguageText(itemMmenuRename, "FilesView.menu.rename");
+		itemMmenuRename.setMenu(menuRename);
+
+			// "Rename or Retarget" -- Opens up file chooser (can choose new dir and new name)
+			itemRenameOrRetarget = new MenuItem(menuRename, SWT.PUSH);
+			Messages.setLanguageText(itemRenameOrRetarget, "FilesView.menu.rename");
+			itemRenameOrRetarget.setData("rename", Boolean.valueOf(true));
+			itemRenameOrRetarget.setData("retarget", Boolean.valueOf(true));
+			itemRenameOrRetarget.setData("batch", Boolean.valueOf(false));
+			
+			// "Rename or Retarget (Batch)"
+			itemRenameOrRetargetBatch = new MenuItem(menuRename, SWT.PUSH);
+			Messages.setLanguageText(itemRenameOrRetargetBatch, "FilesView.menu.rename.batch");
+			itemRenameOrRetargetBatch.setData("rename", Boolean.valueOf(true));
+			itemRenameOrRetargetBatch.setData("retarget", Boolean.valueOf(true));
+			itemRenameOrRetargetBatch.setData("batch", Boolean.valueOf(true));
+			itemRenameOrRetargetBatch.setData("dups", Boolean.valueOf(false));
+	
+				// rename duplicates
+			
+			itemRenameDuplicates = new MenuItem(menuRename, SWT.PUSH);
+			Messages.setLanguageText(itemRenameDuplicates, "menu.rename.duplicates");
+			itemRenameDuplicates.setData("rename", Boolean.valueOf(true));
+			itemRenameDuplicates.setData("retarget", Boolean.valueOf(true));
+			itemRenameDuplicates.setData("batch", Boolean.valueOf(true));
+			itemRenameDuplicates.setData("dups", Boolean.valueOf(true));
+			
+		
 		// "Move Files" -- opens up directory chooser
 		itemRetarget = new MenuItem(menu, SWT.PUSH);
 		Messages.setLanguageText(itemRetarget, "FilesView.menu.retarget");
@@ -420,9 +446,11 @@ public class FilesViewMenuUtil
 
 		if (!hasSelection) {
 			itemOpen.setEnabled(false);
+			itemOpenWith.setEnabled(false);
 			itemPriority.setEnabled(false);
 			itemRenameOrRetarget.setEnabled(false);
 			itemRenameOrRetargetBatch.setEnabled(false);
+			itemRenameDuplicates.setEnabled(false);
 			itemRename.setEnabled(false);
 			itemRetarget.setEnabled(false);
 			itemRevertFiles.setEnabled(false);
@@ -456,11 +484,13 @@ public class FilesViewMenuUtil
 
 			DownloadManager	manager = manager_list[j];
 
-			int dm_file_count = manager.getNumFileInfos();
-
+			TOTorrent torrent = manager.getTorrent();
+			
 			if ( !manager.isPersistent()){
+				
 				all_persistent = false;
 			}
+			
 			DiskManagerFileInfo[] files = files_list[j];
 
 			DownloadManagerState dm_state = manager.getDownloadState();
@@ -524,8 +554,7 @@ public class FilesViewMenuUtil
 
 					// only support clearing links for multi-file torrents
 
-				if ( dm_file_count > 1 ){
-
+				if ( torrent != null && !torrent.isSimpleTorrent()){
 
 					if ( !file_nolink.getAbsolutePath().equals( file_link.getAbsolutePath())){
 
@@ -570,6 +599,8 @@ public class FilesViewMenuUtil
 			});
 			
 			itemOpen.setEnabled(open);
+			
+			itemOpenWith.setEnabled(MenuBuildUtils.hasOpenWithMenu( all_files ) && open);
 		}
 
 		// can't rename files for non-persistent downloads (e.g. shares) as these
@@ -577,6 +608,7 @@ public class FilesViewMenuUtil
 
 		itemRenameOrRetarget.setEnabled(all_persistent);
 		itemRenameOrRetargetBatch.setEnabled(all_persistent);
+		itemRenameDuplicates.setEnabled(all_persistent);
 		itemRename.setEnabled(all_persistent);
 		itemRetarget.setEnabled(all_persistent);
 
@@ -599,14 +631,25 @@ public class FilesViewMenuUtil
 		Listener rename_listener = new Listener() {
 			@Override
 			public void handleEvent(Event event) {
-				final boolean rename_it = ((Boolean) event.widget.getData("rename")).booleanValue();
-				final boolean retarget_it = ((Boolean) event.widget.getData("retarget")).booleanValue();
-				final boolean batch = ((Boolean) event.widget.getData("batch")).booleanValue();
-				rename(tv, all_files.toArray( new Object[all_files.size()]), structure_map, rename_it, retarget_it, batch);
+				boolean rename_it = ((Boolean) event.widget.getData("rename")).booleanValue();
+				boolean retarget_it = ((Boolean) event.widget.getData("retarget")).booleanValue();
+				boolean batch = ((Boolean) event.widget.getData("batch")).booleanValue();
+				
+				Boolean dups = (Boolean)event.widget.getData("dups");
+				
+				rename(
+					tv, 
+					all_files.toArray( new Object[all_files.size()]), 
+					structure_map, 
+					rename_it, 
+					retarget_it, 
+					batch,
+					dups != null && dups );
 			}
 		};
 
 		itemRenameOrRetargetBatch.addListener(SWT.Selection, rename_listener);
+		itemRenameDuplicates.addListener(SWT.Selection, rename_listener);
 		itemRenameOrRetarget.addListener(SWT.Selection, rename_listener);
 		itemRename.addListener(SWT.Selection, rename_listener);
 		itemRetarget.addListener(SWT.Selection, rename_listener);
@@ -791,7 +834,8 @@ public class FilesViewMenuUtil
 		Map<DiskManagerFileInfo,String>	structure_map,
 		boolean 						rename_it,
 		boolean 						retarget_it,
-		boolean							batch )
+		boolean							batch,
+		boolean							duplicates )
 	{
 		if (datasources.length == 0) {
 			return;
@@ -806,12 +850,12 @@ public class FilesViewMenuUtil
 		try {
 
 			if ( batch ){
-				
-				StringBuilder details = new StringBuilder( 32*1024 );
-				
+								
 				Map<DownloadManager,Integer> 	dm_map 		= new IdentityHashMap<>();
 				Map<String,DownloadManager>		dm_name_map = new HashMap<>();
 				
+				int max_files = 1;
+				
 				for (int i = 0; i < datasources.length; i++) {
 					
 					DiskManagerFileInfo fileInfo = (DiskManagerFileInfo) datasources[i];
@@ -820,12 +864,21 @@ public class FilesViewMenuUtil
 					
 					if ( !dm_map.containsKey( dm )){
 						
+						max_files = Math.max( max_files,  dm.getNumFileInfos());
+						
 						dm_map.put( dm, i );
 						
 						dm_name_map.put( dm.getInternalName(), dm );
 					}
 				}
 				
+				int pad = 0;
+				
+				while( max_files > 0 ){
+					pad++;
+					max_files /= 10;
+				}
+				
 				Arrays.sort(
 					datasources,
 					new Comparator<Object>()
@@ -849,47 +902,119 @@ public class FilesViewMenuUtil
 						}
 					});
 				
+				StringBuilder details = new StringBuilder( 32*1024 );
+
 				DownloadManager current_dm = null;
 				
-				for (int i = 0; i < datasources.length; i++) {
+				if ( duplicates ){
 					
-					DiskManagerFileInfo fileInfo = (DiskManagerFileInfo) datasources[i];
-					
-					DownloadManager dm = fileInfo.getDownloadManager();
-					
-					if ( dm != current_dm ){
+					Set<String>		names = new HashSet<>();
+										
+					for (int i = 0; i < datasources.length; i++) {
 						
-						if ( dm_map.size() > 1 ){
+						DiskManagerFileInfo fileInfo = (DiskManagerFileInfo) datasources[i];
+						
+						String current_name = fileInfo.getFile( true ).getAbsolutePath();
+						
+						int suffix = 1;
+						
+						String final_name		= current_name;
+						String lc_final_name	= final_name.toLowerCase( Locale.US );
+						
+						while( names.contains( lc_final_name )){
+						
+							int pos = current_name.lastIndexOf( "." );
 							
-							if ( current_dm != null ){
-								details.append( "\n" );
+							if ( pos == -1 ){
+								
+								final_name = current_name + "_" + suffix;
+								
+							}else{
+								
+								final_name = current_name.substring( 0, pos ) + "_" + suffix + current_name.substring( pos );
 							}
 							
-							details.append( "# " + dm.getInternalName() + " - " );
-							details.append( dm.getDisplayName());
-							details.append( "\n\n" );
+							lc_final_name	= final_name.toLowerCase( Locale.US );
+							
+							suffix++;
 						}
 						
-						current_dm = dm;
-					}
-					
-					String index_str = String.valueOf( fileInfo.getIndex() + 1 );
-					
-					while( index_str.length() < 5 ){
+						names.add( lc_final_name );
 						
-						index_str += " ";
+						if ( suffix > 1 ){
+							
+							DownloadManager dm = fileInfo.getDownloadManager();
+							
+							if ( dm != current_dm ){
+								
+								if ( dm_map.size() > 1 ){
+									
+									if ( current_dm != null ){
+										details.append( "\n" );
+									}
+									
+									details.append( "# " + dm.getInternalName() + " - " );
+									details.append( dm.getDisplayName());
+									details.append( "\n\n" );
+								}
+								
+								current_dm = dm;
+							}
+							
+							String index_str = String.valueOf( fileInfo.getIndex() + 1 );
+							
+							while( index_str.length() <= pad ){
+								
+								index_str += " ";
+							}
+							
+							details.append( index_str );
+							details.append( final_name );
+							details.append( "\n" );
+						}
 					}
 					
-					details.append( index_str );
-					details.append( fileInfo.getFile( true ).getAbsolutePath());
-					details.append( "\n" );
+				}else{
+					for (int i = 0; i < datasources.length; i++) {
+						
+						DiskManagerFileInfo fileInfo = (DiskManagerFileInfo) datasources[i];
+						
+						DownloadManager dm = fileInfo.getDownloadManager();
+						
+						if ( dm != current_dm ){
+							
+							if ( dm_map.size() > 1 ){
+								
+								if ( current_dm != null ){
+									details.append( "\n" );
+								}
+								
+								details.append( "# " + dm.getInternalName() + " - " );
+								details.append( dm.getDisplayName());
+								details.append( "\n\n" );
+							}
+							
+							current_dm = dm;
+						}
+						
+						String index_str = String.valueOf( fileInfo.getIndex() + 1 );
+						
+						while( index_str.length() <= pad ){
+							
+							index_str += " ";
+						}
+						
+						details.append( index_str );
+						details.append( fileInfo.getFile( true ).getAbsolutePath());
+						details.append( "\n" );
+					}
 				}
 				
 				TextViewerWindow viewer =
 						new TextViewerWindow(
 		        			  Utils.findAnyShell(),
 		        			  "batch.retarget.title",
-		        			  "batch.retarget.text",
+		        			  duplicates?"batch.rename.dups.text":"batch.retarget.text",
 		        			  details.toString(), true, true );
 
 				viewer.setEditable( true );
@@ -1527,12 +1652,8 @@ public class FilesViewMenuUtil
 				dm.setFilePriorities(fileInfos, -1);
 			}
 
-			boolean paused = setSkipped(dm, fileInfos, skipped, delete_action?1:0, prompt );
+			setSkipped(dm, fileInfos, skipped, delete_action?1:0, prompt );
 
-			if (paused) {
-
-				dm.resume();
-			}
 		}
 	}
 
@@ -1559,12 +1680,7 @@ public class FilesViewMenuUtil
 			ArrayList<DiskManagerFileInfo> list = mapDMtoDMFI.get(dm);
 			DiskManagerFileInfo[] fileInfos = list.toArray(new DiskManagerFileInfo[0]);
 
-			boolean paused = setSkipped(dm, fileInfos, skipped, delete_action, prompt );
-
-			if (paused) {
-
-				dm.resume();
-			}
+			setSkipped(dm, fileInfos, skipped, delete_action, prompt );
 		}
 	}
 	
@@ -1615,12 +1731,7 @@ public class FilesViewMenuUtil
 				for (DownloadManager dm : mapDMtoDMFI.keySet()) {
 					ArrayList<DiskManagerFileInfo> list = mapDMtoDMFI.get(dm);
 					DiskManagerFileInfo[] fileInfos = list.toArray(new DiskManagerFileInfo[0]);
-					boolean paused = setSkipped(dm, fileInfos, false, 0, true);
-
-					if (paused) {
-
-						dm.resume();
-					}
+					setSkipped(dm, fileInfos, false, 0, true);
 				}
 			}
 		});
@@ -1684,12 +1795,7 @@ public class FilesViewMenuUtil
 		for (DownloadManager dm : mapDMtoDMFI.keySet()) {
 			ArrayList<DiskManagerFileInfo> list = mapDMtoDMFI.get(dm);
 			DiskManagerFileInfo[] fileInfos = list.toArray(new DiskManagerFileInfo[0]);
-			boolean paused = setSkipped(dm, fileInfos, false, 0, true);
-
-			if (paused) {
-
-				dm.resume();
-			}
+			setSkipped(dm, fileInfos, false, 0, true);
 		}
 	}
 	
@@ -2241,7 +2347,7 @@ public class FilesViewMenuUtil
 	 * @param prompt
 	 * @return
 	 */
-	private static boolean 
+	private static void 
 	setSkipped(
 		DownloadManager			manager,
 		DiskManagerFileInfo[]	infos, 
@@ -2256,7 +2362,7 @@ public class FilesViewMenuUtil
 			for (int i = 0; i < infos.length; i++) {
 				infos[i].setSkipped(skipped);
 			}
-			return false;
+			return;
 		}
 		int[] existing_storage_types = manager.getStorageType(infos);
 		int nbFiles = manager.getDiskManagerFileInfoSet().nbFiles();
@@ -2381,50 +2487,61 @@ public class FilesViewMenuUtil
 		}
 
 		boolean ok = true;
-		boolean paused = false;
-		if (type_has_been_changed) {
-			if (requires_pausing)
-				paused = manager.pause( true );
-			if (linearCount > 0)
-				ok &= Arrays.equals(
-						setLinear,
-						manager.getDiskManagerFileInfoSet().setStorageTypes(setLinear,
-								DiskManagerFileInfo.ST_LINEAR));
-			if (compactCount > 0)
-				ok &= Arrays.equals(
-						setCompact,
-						manager.getDiskManagerFileInfoSet().setStorageTypes(setCompact,
-								DiskManagerFileInfo.ST_COMPACT));
-			if (reorderCount > 0)
-				ok &= Arrays.equals(
-						setReorder,
-						manager.getDiskManagerFileInfoSet().setStorageTypes(setReorder,
-								DiskManagerFileInfo.ST_REORDER));
-			if (reorderCompactCount > 0)
-				ok &= Arrays.equals(
-						setReorderCompact,
-						manager.getDiskManagerFileInfoSet().setStorageTypes(setReorderCompact,
-								DiskManagerFileInfo.ST_REORDER_COMPACT));
-		}
-
-		if (ok) {
-			boolean[] toChange = new boolean[nbFiles];
-			
-			for (int i = 0; i < infos.length; i++) {
-				if ( infos[i].isSkipped() != skipped ){
-					toChange[infos[i].getIndex()] = true;
+		
+		boolean paused		= false;
+		int		target_state = 0;
+		
+		try{
+			if (type_has_been_changed) {
+				if (requires_pausing){
+					target_state = manager.getState();
+					paused = manager.pause( true );
 				}
+				if (linearCount > 0)
+					ok &= Arrays.equals(
+							setLinear,
+							manager.getDiskManagerFileInfoSet().setStorageTypes(setLinear,
+									DiskManagerFileInfo.ST_LINEAR));
+				if (compactCount > 0)
+					ok &= Arrays.equals(
+							setCompact,
+							manager.getDiskManagerFileInfoSet().setStorageTypes(setCompact,
+									DiskManagerFileInfo.ST_COMPACT));
+				if (reorderCount > 0)
+					ok &= Arrays.equals(
+							setReorder,
+							manager.getDiskManagerFileInfoSet().setStorageTypes(setReorder,
+									DiskManagerFileInfo.ST_REORDER));
+				if (reorderCompactCount > 0)
+					ok &= Arrays.equals(
+							setReorderCompact,
+							manager.getDiskManagerFileInfoSet().setStorageTypes(setReorderCompact,
+									DiskManagerFileInfo.ST_REORDER_COMPACT));
 			}
+	
+			if (ok) {
+				boolean[] toChange = new boolean[nbFiles];
+				
+				for (int i = 0; i < infos.length; i++) {
+					if ( infos[i].isSkipped() != skipped ){
+						toChange[infos[i].getIndex()] = true;
+					}
+				}
+				
+				manager.getDiskManagerFileInfoSet().setSkipped(toChange, skipped );
+				/*
+				for (int i = 0; i < infos.length; i++) {
+					infos[i].setSkipped(skipped);
+				}
+				*/
+			}
+		}finally{
 			
-			manager.getDiskManagerFileInfoSet().setSkipped(toChange, skipped );
-			/*
-			for (int i = 0; i < infos.length; i++) {
-				infos[i].setSkipped(skipped);
+			if ( paused ){
+			
+				manager.resume( target_state );
 			}
-			*/
 		}
-
-		return paused;
 	}
 
 	public static void
