@@ -155,7 +155,7 @@ TorrentOptionsView
 		}
 		
 		if (showHeader) {
-			Composite cHeader = new Composite(panel, SWT.BORDER);
+			Composite cHeader = new Composite(panel, Utils.isDarkAppearanceNativeWindows()?SWT.NONE:SWT.BORDER);
 			GridLayout configLayout = new GridLayout();
 			configLayout.marginHeight = 3;
 			configLayout.marginWidth = 0;
