@@ -578,6 +578,14 @@ public class SBC_TagsOverview
 					}
 				});
 		
+		tableManager.registerColumn(Tag.class, ColumnTagsSortAutoApply.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnTagsSortAutoApply(column);
+					}
+				});
+
 		tableManager.setDefaultColumnNames(TABLE_TAGS,
 				new String[] {
 					ColumnTagColor.COLUMN_ID,
@@ -727,6 +735,8 @@ public class SBC_TagsOverview
 				tooltip += MessageText.getString("tagsoverview.filter.tt.line2");
 				
 				filter.setTooltip( tooltip );
+				
+				filter.setMessage( MessageText.getString( "Button.search2" ) );
 			}
 
 			tv.setRowDefaultHeightEM(1);
@@ -1236,7 +1246,7 @@ public class SBC_TagsOverview
 		}
 			// if we're not active then ignore this update as we don't want invisible components
 			// updating the toolbar with their invisible selection. Note that unfortunately the
-			// call we get here when activating a view does't yet have focus
+			// call we get here when activating a view doesn't yet have focus
 
 		if ( !isVisible()){
 			if ( !force ){
