@@ -688,7 +688,7 @@ public abstract class TableViewSWT_Common
 	}
 
 	public void runDefaultAction(int stateMask, int origin ) {
-		// Don't allow mutliple run defaults in quick succession
+		// Don't allow multiple run defaults in quick succession
 		if (lastSelectionTriggeredOn > 0
 				&& System.currentTimeMillis() - lastSelectionTriggeredOn < 200) {
 			return;
@@ -937,27 +937,27 @@ public abstract class TableViewSWT_Common
 
 		// Add Plugin Context menus..
 		boolean enable_items = selectedRows.length > 0;
+		boolean needsSeparator = false;
 
 		TableContextMenuItem[] items = TableContextMenuManager.getInstance().getAllAsArray(
 				Utils.getBaseViewID(sMenuID));
 
 		if (items.length > 0 || menu_items.length > 0) {
 			new org.eclipse.swt.widgets.MenuItem(menu, SWT.SEPARATOR);
+			needsSeparator = true;
 
 			// Add download context menu items.
-			if (menu_items != null) {
+			Object[] target;
+			if (isDownloadContext) {
 				// getSelectedDataSources(false) returns us plugin items.
-				Object[] target;
-				if (isDownloadContext) {
-					Object[] dataSources = tv.getSelectedDataSources(false);
-					target = new Download[dataSources.length];
-					System.arraycopy(dataSources, 0, target, 0, target.length);
-				} else {
-					target = selectedRows;
-				}
-				MenuBuildUtils.addPluginMenuItems(menu_items, menu, true, true,
-						new MenuBuildUtils.MenuItemPluginMenuControllerImpl(target));
+				Object[] dataSources = tv.getSelectedDataSources(false);
+				target = new Download[dataSources.length];
+				System.arraycopy(dataSources, 0, target, 0, target.length);
+			} else {
+				target = selectedRows;
 			}
+			MenuBuildUtils.addPluginMenuItems(menu_items, menu, true, true,
+					new MenuBuildUtils.MenuItemPluginMenuControllerImpl(target));
 
 			if (items.length > 0) {
 				MenuBuildUtils.addPluginMenuItems(items, menu, true, enable_items,
@@ -1014,6 +1014,7 @@ public abstract class TableViewSWT_Common
 				TableContextMenuItem[] columnItems = column.getContextMenuItems(TableColumnCore.MENU_STYLE_COLUMN_DATA);
 				if (columnItems.length > 0) {
 					new MenuItem(menu, SWT.SEPARATOR);
+					needsSeparator = true;
 
 					MenuBuildUtils.addPluginMenuItems(
 							columnItems,
@@ -1025,6 +1026,10 @@ public abstract class TableViewSWT_Common
 
 				}
 			}
+			
+			if (needsSeparator) {
+				new MenuItem(menu, SWT.SEPARATOR);
+			}
 
 			final MenuItem itemSelectAll = new MenuItem(menu, SWT.PUSH);
 			Messages.setLanguageText(itemSelectAll, "Button.selectAll");
@@ -1216,7 +1221,7 @@ public abstract class TableViewSWT_Common
 			menuHideColumn.addListener(SWT.Selection,
 					e -> TableColumnSWTUtils.changeColumnVisiblity(tv, column, false));
 		}
-
+		
 		final MenuItem itemResetColumns = new MenuItem(menu, SWT.PUSH);
 		Messages.setLanguageText(itemResetColumns, "table.columns.reset");
 		itemResetColumns.addListener(SWT.Selection, new Listener() {
@@ -1245,6 +1250,12 @@ public abstract class TableViewSWT_Common
 			}
 		});
 
+		final MenuItem itemSelectAll = new MenuItem(menu, SWT.PUSH);
+		Messages.setLanguageText(itemSelectAll, "Button.selectAll");
+		itemSelectAll.addListener(SWT.Selection, (ev)->{
+			tv.selectAll();
+		});
+
 		final MenuItem itemChangeTable = new MenuItem(menu, SWT.PUSH);
 		Messages.setLanguageText(itemChangeTable,
 				"MyTorrentsView.menu.editTableColumns");
